Reference Guides
****************

These documentation section contains technical references to understand the implementation and the exact functionality
of balder. These sections assume that you have a basic understanding of the key concepts described in
[Basic Guides](#basic-guides).

.. toctree::
    :maxdepth: 2
    :caption: Reference Guides

    process.rst
    connections.rst
    connection_lifecycle.rst
    metadata_management.rst
